#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#
#     Authors:
#       Joan Sala Calero (joan.sala@bsc.es)

from pathlib import Path
import pandas as pd
import numpy as np
import sys

# Custom packages
from dqc_downloader.utils_download import *

def main():

    # Params
    if len(sys.argv) != 3:
        print('USAGE: python download_seasonal.py <config_file> <credentials_file>')
        exit()
    else:
        conf_path = sys.argv[1]
        cred_path = sys.argv[2]

    # General configuration
    with open('./conf/download_options.json') as json_file:
        conf = json.load(json_file)
        outputdir = conf['outdir']
        cds_forms_c3s_location = Path(conf['formsdir'])

    # URL and key to download
    with open(cred_path) as json_file:
        cred = json.load(json_file)

    # Read list of products to download
    with open(conf_path) as json_file:
        data = json.load(json_file)

        # For every dataset
        for prod in data:

            # Get constraints for this dataset
            constraints = get_constraints(prod['dataset'], cds_forms_c3s_location, "constraints")
            origin = prod['form']['originating_centre']
            system = prod['form']['system']

            # For every variable
            for var in prod['variables']:

                # Load into pandas table
                df = pd.DataFrame()
                for c in constraints:
                    df = df.append(c, ignore_index=True)

                # Select variable/origin/system
                drops = []
                for ind, row in df.iterrows():
                    if origin in row['originating_centre'] and system in row['system'] and var in row['variable']:
                        # We do not need the rest
                        row['variable'] = var
                    else:
                        drops.append(ind)
                df = df.drop(drops)

                # Group by year/month
                downloads = {}
                for ind, row in df.iterrows():
                    years, months = get_row_dates(row)

                    for y in years:
                        for m in months:
                            row['month'] = m
                            row['year'] = y
                            key = '{}{}01'.format(y,m)
                            if key in downloads:
                                downloads[key]['product_type'] = list(set(downloads[key]['product_type'] + row['product_type']))
                            else:
                                downloads[key] = row.to_dict()


                for k,v in downloads.items():
                    print(k, v)




if __name__ == "__main__":
    main()